"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
var _reactRedux = require("react-redux");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _logging = require("@edx/frontend-platform/logging");
var _i18n = require("@edx/frontend-platform/i18n");
var _paragon = require("@openedx/paragon");
var _insertlink = require("../../data/redux/insertlink");
var _BaseModal = _interopRequireDefault(require("../BaseModal"));
var _BlocksList = _interopRequireDefault(require("./BlocksList"));
var _BlockLink = _interopRequireDefault(require("./BlockLink"));
var _SearchBlocks = _interopRequireDefault(require("./SearchBlocks"));
var _utils = require("./utils");
var _api = require("./api");
var _messages = _interopRequireDefault(require("./messages"));
require("./index.scss");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const InsertLinkModal = _ref => {
  let {
    courseId,
    isOpen,
    onClose,
    editorRef
  } = _ref;
  const intl = (0, _i18n.useIntl)();
  const [searchField, setSearchField] = (0, _react.useState)('');
  const [blocksSearched, setBlocksSearched] = (0, _react.useState)(false);
  const [blockSelected, setBlocksSelected] = (0, _react.useState)(null);
  const [blocksList, setBlocksList] = (0, _react.useState)(null);
  const [, setInvalidUrlInput] = (0, _react.useState)(false);
  const [inputUrlValue, setInputUrlValue] = (0, _react.useState)('');
  const [errorUrlNotSelected, setErrorUrlNotSelected] = (0, _react.useState)(false);
  const dispatch = (0, _reactRedux.useDispatch)();
  const {
    selectedBlocks
  } = (0, _reactRedux.useSelector)(_insertlink.selectors.insertlinkState);
  const handleSearchedBlocks = isSearched => {
    setBlocksSearched(isSearched);
  };
  const handleSelectedBlock = blockSelectedFromList => {
    setBlocksSelected(blockSelectedFromList);
    setInputUrlValue('');
  };
  const handleCloseLink = () => {
    setSearchField('');
    setBlocksSelected(null);
  };

  /* istanbul ignore next */
  const handleSave = () => {
    const editor = editorRef.current;
    const urlPath = blockSelected?.lmsWebUrl || inputUrlValue;
    const blockId = blockSelected?.blockId;
    if (editor && urlPath) {
      const validateUrl = (0, _utils.isValidURL)(urlPath);
      if (!validateUrl) {
        setInvalidUrlInput(true);
        return;
      }
      const selectedRange = editor.selection.getRng();
      const selectedText = editor.selection.getContent({
        format: 'text'
      });
      const newLinkNode = editor.dom.create('a', {
        href: urlPath,
        'data-mce-href': urlPath,
        'data-block-id': blockId,
        target: '_blank'
      });
      newLinkNode.textContent = selectedText;
      selectedRange.deleteContents();
      selectedRange.insertNode(newLinkNode);
      // Remove empty "a" tags after replacing URLs
      const editorContent = editor.getContent();
      const modifiedContent = editorContent.replace(/<a\b[^>]*><\/a>/gi, '');
      editor.setContent(modifiedContent);
      dispatch(_insertlink.actions.addBlock({
        [blockId]: blockSelected
      }));
    }
    onClose();
  };
  (0, _react.useEffect)(() => {
    const getBlocksList = async () => {
      try {
        const blocksData = await (0, _api.getBlocksFromCourse)(courseId);
        const {
          blocks: blocksResponse,
          root: rootBlocksResponse
        } = blocksData;
        const blockListFormatted = (0, _utils.formatBlocks)(blocksResponse, rootBlocksResponse);
        setBlocksList(blockListFormatted);
      } catch (error) {
        (0, _logging.logError)(error);
      }
    };
    getBlocksList();
  }, []);
  (0, _react.useEffect)(() => {
    /* istanbul ignore next */
    const editor = editorRef.current;
    if (editor) {
      const selectedHTML = editor.selection.getContent({
        format: 'html'
      });
      const regex = /data-block-id="([^"]+)"/;
      const match = selectedHTML.match(regex);

      // Extracting the value from the match
      const dataBlockId = match ? match[1] : null;
      if (selectedHTML && !dataBlockId) {
        const selectedNode = editor.selection.getNode();
        const parentNode = editor.dom.getParent(selectedNode, 'a');
        if (parentNode) {
          const dataBlockIdParent = parentNode.getAttribute('data-block-id');
          const blockIsValid = (dataBlockIdParent in selectedBlocks);
          if (dataBlockIdParent && blockIsValid) {
            setBlocksSelected(selectedBlocks[dataBlockIdParent]);
          }
        }
      }
      if (dataBlockId) {
        const blockIsValid = (dataBlockId in selectedBlocks);
        if (dataBlockId && blockIsValid) {
          setBlocksSelected(selectedBlocks[dataBlockId]);
        }
      }
      if (!selectedHTML) {
        setErrorUrlNotSelected(true);
      }
    }
  }, []);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_BaseModal.default, {
    isOpen: isOpen,
    close: onClose,
    title: intl.formatMessage(_messages.default.insertLinkModalTitle),
    confirmAction: /*#__PURE__*/(0, _jsxRuntime.jsx)(_paragon.Button, {
      variant: "primary",
      onClick: handleSave,
      disabled: errorUrlNotSelected,
      children: intl.formatMessage(_messages.default.insertLinkModalButtonSave)
    }),
    children: blockSelected ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_BlockLink.default, {
      path: blockSelected.path,
      onCloseLink: handleCloseLink
    }) : /*#__PURE__*/(0, _jsxRuntime.jsx)(_paragon.Tabs, {
      variant: "tabs",
      defaultActiveKey: "course-pages",
      id: "uncontrolled-tab-example",
      className: "mt-3 justify-content-around w-100",
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_paragon.Tab, {
        eventKey: "course-pages",
        title: intl.formatMessage(_messages.default.insertLinkModalCoursePagesTabTitle),
        className: "col-12 w-100 tabs-container",
        children: [errorUrlNotSelected && /*#__PURE__*/(0, _jsxRuntime.jsx)(_paragon.Form.Control.Feedback, {
          type: "invalid",
          className: "mt-4",
          children: intl.formatMessage(_messages.default.insertLinkModalUrlNotSelectedErrorMessage)
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_SearchBlocks.default, {
          blocks: blocksList || {},
          onSearchFilter: handleSearchedBlocks,
          searchInputValue: searchField,
          onBlockSelected: handleSelectedBlock,
          disabledBlocks: errorUrlNotSelected
        }), !blocksSearched && /*#__PURE__*/(0, _jsxRuntime.jsx)(_BlocksList.default, {
          blocks: blocksList || {},
          onBlockSelected: handleSelectedBlock,
          disableBlocks: errorUrlNotSelected
        })]
      })
    })
  });
};
InsertLinkModal.propTypes = {
  courseId: _propTypes.default.string.isRequired,
  isOpen: _propTypes.default.bool.isRequired,
  onClose: _propTypes.default.func.isRequired,
  editorRef: _propTypes.default.shape({
    current: _propTypes.default.shape({
      selection: _propTypes.default.shape({
        getContent: _propTypes.default.func,
        setContent: _propTypes.default.func,
        getRng: _propTypes.default.func,
        // Add this line
        getNode: _propTypes.default.func // Add this line
      }),
      getContent: _propTypes.default.func,
      setContent: _propTypes.default.func,
      dom: _propTypes.default.shape({
        create: _propTypes.default.func,
        getParent: _propTypes.default.func
      })
    })
  }).isRequired
};
var _default = exports.default = InsertLinkModal;
//# sourceMappingURL=index.js.map